@@ -258,7 +258,7 @@ class Get_ASM_Consume:
             if float(today_credits_num) != yes_credits_num:
                 yes_run_num = round(yes_credits_num - today_credits_num, 2)  # 昨日消耗的；
                 # now_yue_num = budget_amount - spent_value  # 限制消耗金额减去当前总消耗
-                now_yue_days = int(math.floor(yes_run_num / today_credits_num))  # 预估还可消耗天数；
+                now_yue_days = int(math.floor(float(today_credits_num) / yes_run_num))  # 预估还可消耗天数；
             else:
                 # 如果今日昨日一样，代表没消耗的，就可以跳过；
                 yes_run_num = '空'
